@@ -185,6 +185,10 @@ gb_button_normal_find_child_widgets (GtkWidget *widget,
   /* Check if it has just a GtkLabel child. */
   if (GTK_IS_LABEL (child))
     {
+      /* If it is a GbWidget we don't handle its properties here. */
+      if (GB_IS_GB_WIDGET (child))
+	return FALSE;
+
       *label = child;
       return TRUE;
     }
