@@ -36,6 +36,7 @@ static GbWidget gbwidget;
 static gchar *StockButton = "RadioButton|GtkButton::stock_button";
 static gchar *Label = "RadioButton|GtkButton::label";
 static gchar *Icon = "RadioButton|GtkButton::icon";
+static gchar *FocusOnClick = "RadioButton|GtkButton::focus_on_click";
 
 /* This is only used for normal/stock buttons, not special toolbar buttons,
    as the toolbar has its own relief setting. */
@@ -95,14 +96,6 @@ gb_radio_button_new (GbWidgetNewData * data)
   GtkWidget *new_widget;
   GSList *group_list = NULL;
 
-  /* SPECIAL CODE: to handle toolbar buttons. */
-  if (data->parent && GTK_IS_TOOLBAR (data->parent))
-    {
-      new_widget = gb_toolbar_new_toolbar_button (data, GTK_TOOLBAR_CHILD_RADIOBUTTON);
-      if (new_widget)
-	return new_widget;
-    }
-
   /* When creating a radiobutton we try to place it in the same group as other
      radio buttons with the same parent. */
   if (data->parent && data->action == GB_CREATING)
@@ -152,6 +145,7 @@ gb_radio_button_create_properties (GtkWidget * widget, GbWidgetCreateArgData *
 		      NULL);
   combo = property_get_value_widget (Group);
   gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
+  property_add_bool (FocusOnClick, _("Focus On Click:"), _("If the button grabs focus when it is clicked"));
 }
 
 
@@ -164,26 +158,20 @@ static void
 gb_radio_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 {
   GtkWidget *component;
-  gboolean is_toolbar_button;
   GladeFindGroupData find_data;
 
   component = glade_util_get_toplevel (widget);
 
   gb_button_get_standard_properties (widget, data, StockButton, Label, Icon,
-				     Relief);
-
-  is_toolbar_button = gb_toolbar_is_toolbar_button (widget);
+				     Relief, FocusOnClick);
 
   gb_widget_output_bool (data, State, data->widget_data->flags & GLADE_ACTIVE);
 
   gb_widget_output_bool (data, Inconsistent,
 			 GTK_TOGGLE_BUTTON (widget)->inconsistent);
 
-  if (!is_toolbar_button)
-    {
-      gb_widget_output_bool (data, Indicator,
-			     GTK_TOGGLE_BUTTON (widget)->draw_indicator);
-    }
+  gb_widget_output_bool (data, Indicator,
+			 GTK_TOGGLE_BUTTON (widget)->draw_indicator);
 
   /* If we're showing we need to display the list of groups to choose from.
      We walk the tree of widgets in this component, and if a widget is
@@ -204,7 +192,7 @@ gb_radio_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
       g_list_free (find_groups_data.groups_found);
       g_list_free (find_groups_data.group_names);
 
-      property_set_visible (Indicator, !is_toolbar_button);
+      /*property_set_visible (Indicator, !is_toolbar_button);*/
     }
 
   find_data.group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
@@ -327,7 +315,7 @@ gb_radio_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
   gchar *group_name;
 
   gb_button_set_standard_properties (widget, data, StockButton, Label, Icon,
-				     Relief);
+				     Relief, FocusOnClick);
 
   state = gb_widget_input_bool (data, State);
   if (data->apply)
