@@ -115,8 +115,9 @@ static GladeError* source_create_file_if_not_exist (const gchar *directory,
 						    const gchar *filename,
 						    const gchar *contents);
 static void source_write_po_files (GbWidgetWriteSourceData * data);
+#if 0
 static void source_write_acconfig_h (GbWidgetWriteSourceData * data);
-
+#endif
 static void source_write_support_files (GbWidgetWriteSourceData * data);
 
 static void source_write_gtk_create_pixmap_functions (GbWidgetWriteSourceData * data,
@@ -1073,7 +1074,7 @@ source_write_gtk_configure_in (GbWidgetWriteSourceData * data)
       fprintf (fp,
 	       "GETTEXT_PACKAGE=%s\n"
 	       "AC_SUBST(GETTEXT_PACKAGE)\n"
-	       "AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,\"$GETTEXT_PACKAGE\")\n\n",
+	       "AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,\"$GETTEXT_PACKAGE\", [Gettext package.])\n\n",
 	       data->program_name);
       fprintf (fp,
 	       "dnl Add the languages which your application supports here.\n"
@@ -1362,7 +1363,7 @@ source_write_gnome_configure_in (GbWidgetWriteSourceData * data)
       fprintf (fp,
 	       "GETTEXT_PACKAGE=%s\n"
 	       "AC_SUBST(GETTEXT_PACKAGE)\n"
-	       "AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,\"$GETTEXT_PACKAGE\")\n\n",
+	       "AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,\"$GETTEXT_PACKAGE\", [Gettext package.])\n\n",
 	       data->program_name);
       fprintf (fp,
 	       "dnl Add the languages which your application supports here.\n"
@@ -1602,7 +1603,9 @@ source_write_common_build_files (GbWidgetWriteSourceData * data)
   if (data->error)
     return;
 
+#if 0
   source_write_acconfig_h (data);
+#endif
 }
 
 
@@ -1822,6 +1825,7 @@ source_write_po_files (GbWidgetWriteSourceData * data)
 }
 
 
+#if 0
 static void
 source_write_acconfig_h (GbWidgetWriteSourceData * data)
 {
@@ -1860,6 +1864,7 @@ source_write_acconfig_h (GbWidgetWriteSourceData * data)
 
   g_free (filename);
 }
+#endif
 
 
 /*************************************************************************
@@ -2489,10 +2494,8 @@ source_make_string_internal (const gchar * text,
   gchar escape_buffer[16];
   const gchar *p;
 
-  g_return_val_if_fail (text != NULL, "\"\"");
-
   /* If the text is empty, we return an empty string without the _ macro. */
-  if (text[0] == '\0')
+  if (!text || text[0] == '\0')
     return "\"\"";
 
   /* Create the buffer if it hasn't already been created. */
