@@ -2140,8 +2140,9 @@ glade_util_set_file_selection_filename (GtkWidget *filesel,
   
   on_disk_filename = g_filename_from_utf8 (filename_utf8, -1, NULL, NULL,
 					   NULL);
-  gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel),
-				   on_disk_filename);
+
+  gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (filesel),
+				 on_disk_filename);
   g_free (on_disk_filename);
 }
 
@@ -2154,7 +2155,7 @@ glade_util_get_file_selection_filename (GtkWidget *filesel)
   const gchar *on_disk_filename;
   gchar *filename;
   
-  on_disk_filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel));
+  on_disk_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
   filename = g_filename_to_utf8 (on_disk_filename, -1, NULL, NULL, NULL);
   return filename;
 }
